Resources
==============

.. toctree::
   :maxdepth: 4

   prem.resources.completions
   prem.resources.embeddings
   prem.resources.datapoints

.. automodule:: prem.resources
   :members:
   :undoc-members:
   :show-inheritance:
